@@ -1,5 +1,4 @@
 
-#' @importFrom utils download.file
 #' @import dplyr
 
 # given a catalogue number, download the catalogue metadata via XML, then find
@@ -28,7 +27,8 @@ get_abs_xml_metadata <- function(url, issue = "latest") {
   # doesn't work then we try with a leading zero ("01"). If that fails,
   # it's an error.
 
-  first_page <- xml2::read_xml(first_url, encoding = "ISO-8859-1")
+  first_page <- xml2::read_xml(first_url, encoding = "ISO-8859-1",
+                               user_agent = readabs_user_agent)
   first_page_list <- xml2::as_list(first_page)
   first_page_list <- first_page_list[[1]]
   first_url_works <- ifelse(length(first_page_list) > 0,
