@@ -15,7 +15,7 @@
 #' @export
 #'
 read_abs_data <- function(path, sheet) {
-  Date = series = value = NULL
+  Date <- series <- value <- NULL
   df <- readxl::read_excel(path = path, sheet = sheet)
   dat <- df[-(1:9), ]
   colnames(dat)[1] <- "Date"
@@ -23,9 +23,11 @@ read_abs_data <- function(path, sheet) {
   dat <- tidyr::gather(dat, `series`, `value`, -`Date`)
   dat$value <- as.numeric(dat$`value`)
 
-  .Deprecated(new = "read_abs_local()",
-              old = "read_abs_data()",
-              msg = "read_abs_data() is deprecated and will be removed in a future version. Please use read_abs_local().")
+  .Deprecated(
+    new = "read_abs_local()",
+    old = "read_abs_data()",
+    msg = "read_abs_data() is deprecated and will be removed in a future version. Please use read_abs_local()."
+  )
 
   return(dat)
 }
@@ -48,15 +50,19 @@ read_abs_metadata <- function(path, sheet) {
   rownames(final_dat) <- NULL
   final_dat <- as.data.frame(final_dat, stringsAsFactors = FALSE)
   final_dat$`Series Start` <- as.Date(as.integer(final_dat$`Series Start`),
-                                      origin = "1899-12-30")
+    origin = "1899-12-30"
+  )
   final_dat$`Series End` <- as.Date(as.integer(final_dat$`Series End`),
-                                    origin = "1899-12-30")
+    origin = "1899-12-30"
+  )
   colnames(final_dat)[1] <- "Series"
 
-  .Deprecated(new = "read_abs_local()",
-              old = "read_abs_metadata()",
-              msg = "read_abs_metadata() is deprecated and will be removed in a future version. Please use read_abs_local()
-              to read tidy versions of locally-stored time series spreadsheets, or read_abs() to get them from the ABS website.")
+  .Deprecated(
+    new = "read_abs_local()",
+    old = "read_abs_metadata()",
+    msg = "read_abs_metadata() is deprecated and will be removed in a future version. Please use read_abs_local()
+              to read tidy versions of locally-stored time series spreadsheets, or read_abs() to get them from the ABS website."
+  )
 
 
   return(final_dat)
